/***************************************************************************
 $RCSfile: card_p.h,v $
                             -------------------
    cvs         : $Id: card_p.h,v 1.2 2006/01/13 16:51:44 cstim Exp $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef AG_CARD_P_H
#define AG_CARD_P_H

#include "card_l.h"


struct AG_CARD {
  GWEN_LIST_ELEMENT(AG_CARD);
  AB_ACCOUNT *account;
  AB_JOB_LIST2 *bankingJobs;
};



#endif
